%% File: SPW9_proc.cls
%% ---------------------------------
%% LaTeX2e class file for the proceedings of 
%% 9th International Workshop on Solar Polarization 
%% Copyright (C) 2019 Max-Planck-Institut f\"ur Sonnensystemforschung G\"ottingen
%% ---------------------------------
%% Author:
%% Achim Gandorfer, based on "goeproc.cls" by Dieter Schmitt
%% Max-Planck-Institut f\"ur Sonnensystemforschung
%% Justus-von-Liebig-Weg 3
%% D-37077 Göttingen 
%% Germany
%% E-mail: gandorfer@mps.mpg.de
%% ---------------------------------
%% This file may be used for non-profit purposes. 
%% It may not be distributed in exchange of money.
%% The author provides it `as is' and does not
%% guarantee it in any way.

\NeedsTeXFormat{LaTeX2e}[1995/06/01]
\ProvidesClass{SPW9_proc}[2019/11/01 1.0 (AG)]

\LoadClass[twoside]{article}

\paperheight=240mm
\paperwidth=170mm

\ifx\pdfoutput\undefined
   \IfFileExists{graphicx.sty}{\RequirePackage[dvips]{graphicx}% LaTeX
      \DeclareGraphicsExtensions{.eps,.ps}}{%
      \ClassWarningNoLine{SPW9_proc}{Cannot find graphicx.sty; proceeding without it}}
\else
   \ifnum\pdfoutput=0
      \IfFileExists{graphicx.sty}{\RequirePackage[dvips]{graphicx}% LaTeX
         \DeclareGraphicsExtensions{.eps,.ps}}{%
         \ClassWarningNoLine{SPW9_proc}{Cannot find graphicx.sty; proceeding without it}}
   \else
      \IfFileExists{graphicx.sty}{\RequirePackage[pdftex]{graphicx}% pdfLaTeX
         \DeclareGraphicsExtensions{.pdf,.png,.jpg}}{%
         \ClassWarningNoLine{SPW9_proc}{Cannot find graphicx.sty; proceeding without it}}
      \pdfinfo{/Creator (SPW9_proc.cls)}
      \pdfpagewidth=170mm
      \pdfpageheight=240mm
   \fi
\fi

\RequirePackage{authblk}
\RequirePackage{natbib}
\setlength{\bibsep}{0pt}
\bibpunct{(}{)}{;}{a}{}{,}
\def\bibfont{\small}

\IfFileExists{txfonts.sty}{\RequirePackage{txfonts}}{%
   \ClassWarningNoLine{SPW9_proc}{Cannot find txfonts.sty; proceeding without it}}

\IfFileExists{amssymb.sty}{\RequirePackage{amssymb}}{%
   \ClassWarningNoLine{SPW9_proc}{Cannot find amssymb.sty; proceeding without it}}

\DeclareRobustCommand*{\vec}[1]{\ensuremath{%
   \mathchoice{\mbox{\boldmath$\displaystyle#1$}}
              {\mbox{\boldmath$\textstyle#1$}}
              {\mbox{\boldmath$\scriptstyle#1$}}
              {\mbox{\boldmath$\scriptscriptstyle#1$}}}}

\def\testbx{bx}
\DeclareRobustCommand*{\chem}[1]{\ensuremath{%
   \mathcode`-="0200\mathcode`\=="003D% no space around "-" and "="
   \ifx\testbx\f@series\mathbf{#1}\else\mathrm{#1}\fi}}
\DeclareRobustCommand*{\unit}[1]{\ensuremath{\def\mu{\mbox{\textmu}}\def~{\,}%
   \ifx\testbx\f@series\mathbf{#1}\else\mathrm{#1}\fi}}

\def\acknowname{Acknowledgement}
\def\acknowsname{Acknowledgements}
\def\refname{References}
\def\abstractname{Abstract}
\def\appendixname{Appendix}
\def\figurename{Figure}
\def\tablename{Table}
\def\fnum@figure{\sffamily\figurename~\thefigure}
\def\fnum@table{\sffamily\tablename~\thetable}
      
\def\@normalsize{\@setsize\normalsize{12pt}\xpt\@xpt
   \abovedisplayskip 10\p@ plus2\p@ minus5\p@
   \belowdisplayskip \abovedisplayskip
   \abovedisplayshortskip  \z@ plus3\p@
   \belowdisplayshortskip  6\p@ plus3\p@ minus3\p@
   \let\@listi\@listI}
\def\small{%
   \@setsize\small{11pt}\ixpt\@ixpt
   \abovedisplayskip 8.5\p@ plus3\p@ minus4\p@
   \belowdisplayskip \abovedisplayskip
   \abovedisplayshortskip \z@ plus2\p@
   \belowdisplayshortskip 4\p@ plus2\p@ minus2\p@
   \def\@listi{\leftmargin\leftmargini
      \topsep 4\p@ plus2\p@ minus2\p@\parsep 2\p@ plus\p@ minus\p@
      \itemsep \parsep}}
\let\footnotesize=\small
\def\scriptsize{\@setsize\scriptsize{8pt}\viipt\@viipt}
\def\tiny{\@setsize\tiny{6pt}\vpt\@vpt}
\def\large{\@setsize\large{14pt}\xiipt\@xiipt}
\def\Large{\@setsize\Large{18pt}\xivpt\@xivpt}
\def\LARGE{\@setsize\LARGE{22pt}\xviipt\@xviipt}
\def\huge{\@setsize\huge{25pt}\pt\@xxpt}
\def\Huge{\@setsize\Huge{30pt}\xxvpt\@xxvpt}
 
\normalsize

\topmargin=-2.9cm
\headheight=2cm
\headsep=0.5cm
\topskip=12pt
\footskip=0pt
\oddsidemargin=-3.5mm
\evensidemargin=-6.5mm
\textwidth=129mm
\textheight=45\baselineskip
\advance\textheight by \topskip
\parindent=1em
\parskip 0pt plus 1pt

\setcounter{topnumber}{2}
\def\topfraction{1.}
\setcounter{bottomnumber}{0}
\setcounter{totalnumber}{2}
\def\textfraction{0}
\def\floatpagefraction{.7}

\def\section{\@startsection {section}{1}{\z@}{-3.5ex plus -1ex minus
   -0.2ex}{2.3ex plus 0.2ex}{\reset@font\sffamily\normalsize\bfseries}}
\def\subsection{\@startsection{subsection}{2}{\z@}{-3.25ex plus -1ex
   minus -0.2ex}{1.5ex plus 0.2ex}{\reset@font\sffamily\normalsize\mdseries}}
\def\subsubsection{\@startsection{subsubsection}{3}{\z@}{-3.25ex plus
   -1ex minus -0.2ex}{1.5ex plus 0.2ex}{\reset@font\sffamily\normalsize\mdseries}}
\let\paragraph=\subsubsection
\let\subparagraph=\paragraph

\@ifundefined{reset@font}{\let\reset@font=\relax}{}
\setcounter{secnumdepth}{3}

\def\desfont{\sffamily\bfseries\small}
\def\descriptionlabel#1{\hspace\labelsep \desfont #1.}
\def\description{\list{}{\labelwidth\z@ \leftmargin\z@ \itemindent-\leftmargin
   \let\makelabel\descriptionlabel\reset@font\small}}
\let\enddescription\endlist

\long\def\@makecaption#1#2{\vskip 10\p@{\reset@font\small{\bf #1.} #2\par}}

\let\@oxfloat=\@xfloat
\def\@xfloat#1[#2]{\@oxfloat#1[#2]\small}

\def\maketitle{%
   \setcounter{page}{\@fpage}
   \thispagestyle{titlepage}
   \setcounter{footnote}{0}%
   \noindent\begin{minipage}{\hsize}
         \raggedright
         \let\footnotesize\normalsize
         \let\footnoterule\relax
         \def\thefootnote{\fnsymbol{footnote}}%
         \def\@mpfn{footnote}%
         \let\thempfn=\thefootnote
         \renewcommand\@makefntext[1]{%
         \parindent 1em \noindent
         \@makefnmark##1}
         {\vspace{20mm}\center\sffamily\LARGE\bfseries\@title\par}
            \vspace{10pt}
            {\normalsize
            \renewcommand{\Authfont}{\sffamily\bfseries}%
            \renewcommand{\Affilfont}{\reset@font}%
            \setlength{\affilsep}{4pt}%
            \baselineskip 15pt
            \let\and=\sw@and
            \begin{minipage}[t]{\hsize}\flushleft\baselineskip=12pt%
               \center\@author
            \end{minipage}\par}%
         \vspace{20pt}
   \end{minipage}     
}

\renewcommand\and{\@centercr}
\newcommand\sw@and{\end{minipage}\\[1em]\begin{minipage}[t]{\hsize}%
   \flushleft\baselineskip12pt}

\def\pubyear#1{\def\@pyear{#1}}         \def\@pyear{\number\year}
\def\firstpage#1{\def\@fpage{#1}}       \def\@fpage{1}
\def\runningauthor#1{\def\@runauth{#1}} \def\@runauth{}
\def\runningtitle#1{\def\@runtit{#1}}   \def\@runtit{}
\def\runninghead#1{\def\@runhd{#1}}     \def\@runhd{\@runauth: \@runtit}
\def\lastpage@putlabel{\addtocounter{page}{-1}%
   \immediate\write\@auxout{\string
   \newlabel{LastPage}{{}{\thepage}{}{}{}}}%
   \addtocounter{page}{1}}
\AtEndDocument{\clearpage\lastpage@putlabel}
\def\@lpage{\pageref{LastPage}}

\renewenvironment{abstract}{\noindent\begin{minipage}{\hsize}
   \reset@font\small\par\noindent{\sffamily\bfseries\abstractname.} \ignorespaces}{\end{minipage}}
\newenvironment{acknowledgements}{\begin{description}\item[\acknowsname]}{\end{description}}
\newenvironment{acknowledgement}{\begin{description}\item[\acknowname]}{\end{description}}

\def\ps@runninghead{%
   \def\@oddhead{\@runhd\hfil\makebox[\z@][r]{\thepage}}
   \def\@evenhead{\makebox[\z@][l]{\thepage}\hfil\@runhd}
   \def\@oddfoot{}
   \def\@evenfoot{}}

\def\ps@titlepage{%
   \def\@oddhead{\parbox[t]{130mm}{%
      {\bf{\it Proceedings of the 9th Solar Polarization Workshop SPW9}} \\  %\@fpage--\@lpage\\
   A workshop held in G\"ottingen, Germany, from August 26 to August 30, 2019 \\   
      Achim Gandorfer, Andreas Lagg, Kerstin Raab (eds.)\\
      \copyright\ Max-Planck-Institut f\"ur Sonnensystemforschung G\"ottingen 2019\\ 
       {\bf DOI}: %to be filled in later by editors 
   }}
   \let\@evenhead\@oddhead  
   \def\@oddfoot{}
   \def\@evenfoot{}}

\pagenumbering{arabic}

\flushbottom
\ps@runninghead

%% End of file `SPW9_proc.cls'.
